
Here is a simple template and generator script for `.ics` files you can host dynamically, plus a few options for “Add to Calendar” links:

# 🗓️ ICS File Template (Static or Generated)

You can manually generate `.ics` files or create them dynamically with a script.

### ✅ Example `.ics` Content for a Product Demo

Save this as a file named `product-demo.ics` and serve it with `Content-Type: text/calendar`.

```ics
BEGIN:VCALENDAR
VERSION:2.0
PRODID:-//YourCompany//Product Demo//EN
BEGIN:VEVENT
UID:demo-20250612@yourcompany.com
DTSTAMP:20250514T170000Z
DTSTART:20250612T170000Z
DTEND:20250612T173000Z
SUMMARY:Live Zoom Product Demo
DESCRIPTION:Join our demo at https://zoom.us/j/123456789
LOCATION:https://zoom.us/j/123456789
URL:https://zoom.us/j/123456789
END:VEVENT
END:VCALENDAR
```

> Adjust `DTSTART`, `DTEND`, and `DTSTAMP` to your desired date/time in UTC (`Z` at the end means Zulu/UTC time).

---

# 🧰 Node.js Express ICS Generator (Dynamic)

```js
// npm install express
const express = require('express');
const app = express();

app.get('/demo.ics', (req, res) => {
  const start = '20250612T170000Z';
  const end = '20250612T173000Z';
  const ics = `BEGIN:VCALENDAR
VERSION:2.0
PRODID:-//YourCompany//Product Demo//EN
BEGIN:VEVENT
UID:demo-20250612@yourcompany.com
DTSTAMP:20250514T170000Z
DTSTART:${start}
DTEND:${end}
SUMMARY:Live Zoom Product Demo
DESCRIPTION:Join our demo at https://zoom.us/j/123456789
LOCATION:https://zoom.us/j/123456789
URL:https://zoom.us/j/123456789
END:VEVENT
END:VCALENDAR`;

  res.setHeader('Content-Type', 'text/calendar');
  res.setHeader('Content-Disposition', 'attachment; filename=demo.ics');
  res.send(ics);
});

app.listen(3000, () => {
  console.log('ICS server running on http://localhost:3000/demo.ics');
});
```
